- test:
    timeout:
      minutes: {{ timeout }}
    definitions:
    - repository: {{ test_definitions }}
      lava-signal: kmsg
      from: url
      compression: zstd
      path: automated/linux/kunit/kunit.yaml
      name: kunit
      parameters:
        KUNIT_TEST_MODULE: '{{ parameters.get("KUNIT_TEST_MODULE", "kunit-test.ko") }}'

